Module property

Module property 

Structs

AndroidPropertyInfo
AndroidPropertyInfoOpaque
AndroidPropertyValue
SystemAndroidPropertyStore

Traits

AndroidPropertyStore

Functions

find
get
read
Read the current value of an Android system property.
serial
Return the current serial number of an Android system property.
set
Set an Android system property.
wait
Wait for an Android system property to change from its last known serial.