pub fn read(property: AndroidPropertyInfo) -> Result<AndroidPropertyValue>Expand description
Read the current value of an Android system property.
Errors
EINVAL: The property info is invalid.
pub fn read(property: AndroidPropertyInfo) -> Result<AndroidPropertyValue>Read the current value of an Android system property.
EINVAL: The property info is invalid.