pub fn serial(property: AndroidPropertyInfo) -> Result<u32>Expand description
Return the current serial number of an Android system property.
Errors
EINVAL: The property info is invalid.
pub fn serial(property: AndroidPropertyInfo) -> Result<u32>Return the current serial number of an Android system property.
EINVAL: The property info is invalid.