Module android_property

Module android_property 

Structs

AndroidPropertyInfo
AndroidPropertyInfoOpaque
AndroidPropertyValue
SystemAndroidPropertyStore

Traits

AndroidPropertyStore

Functions

android_property_find
android_property_get
android_property_read
Read the current value of an Android system property.
android_property_serial
Return the current serial number of an Android system property.
android_property_set
Set an Android system property.
android_property_wait
Wait for an Android system property to change from its last known serial.