remove_watch

Function remove_watch 

pub fn remove_watch(fd: &Fd, wd: i32) -> Result<(), CoreError>
Remove an existing watch descriptor from an inotify instance.

Errors

  • EBADF: The provided file descriptor is invalid.
  • EINVAL: The watch descriptor wd is invalid for this inotify instance.