read_proc_cmdline

Function read_proc_cmdline 

pub fn read_proc_cmdline(pid: i32) -> Result<String, CoreError>
Read process command line from /proc/<pid>/cmdline.

NUL separators are converted into spaces so the returned string is easier to log or inspect. Read process command line from /proc/<pid>/cmdline.

NUL separators are converted into spaces so the returned string is easier to log or inspect.

Errors

  • EACCES: Permission denied.
  • ENOENT: The process does not exist.