remove_nofollow

Function remove_nofollow 

pub fn remove_nofollow(path: impl AsRef<Path>) -> Result<()>
Remove a directory entry without following a final symlink, anchored to its (symlink-free) parent. The entry itself is removed even if it is a symlink; its target is never touched.