pub struct ShutdownFlagGuard { /* private fields */ }Expand description
Guard that restores previous SIGINT/SIGTERM handlers and shutdown flag on drop.
Fork Safety
The guard is owned by the process that created it. If the process forks, the child will also have a copy of the guard, but dropping it in the child will restore handlers in the child’s context only.