Module uid

Module uid 

Ownership and UID lookup helpers.

These helpers provide cheap ownership probes for filesystem paths and /proc/<pid> directories before higher layers do more expensive work.

Structs

PathStat
Filesystem identity derived from stat(2).

Functions

chown_path
Change the owner of a path while leaving the group unchanged when gid is None.
effective_uid
Return the effective UID of the current process.
path_lstat
Return identity metadata for a filesystem path without following symbolic links.
path_stat
Return identity metadata for a filesystem path, following symbolic links.
path_uid
Return the owning UID for a filesystem path.
proc_stat
Return identity metadata for /proc/<pid>.
proc_stat_at
Return identity metadata for /proc/<pid> under an explicit procfs root.
proc_uid
Return the owning UID for /proc/<pid>.
proc_uid_at
Return the owning UID for /proc/<pid> under an explicit procfs root.