pub fn chown_path(
path: impl AsRef<Path>,
uid: u32,
gid: Option<u32>,
) -> Result<(), CoreError>Expand description
Change the owner of a path while leaving the group unchanged when gid is None.
Errors
EACCES: Permission denied for a component of the path prefix.EPERM: The caller does not have permission to change the owner.ENOENT: The path does not exist.