path_stat

Function path_stat 

pub fn path_stat(path: impl AsRef<Path>) -> Result<PathStat, CoreError>
Return identity metadata for a filesystem path, following symbolic links.

This performs a stat(2) call and captures the fields used by hot-path procfs callers to detect identity changes cheaply without opening procfs text files.