path_uid

Function path_uid 

pub fn path_uid(path: impl AsRef<Path>) -> Result<u32, CoreError>
Return the owning UID for a filesystem path.

This performs a stat(2) call and returns the owner UID from the resulting metadata. Missing files, permission errors, and invalid path bytes are surfaced as CoreError. Return the owning UID for a filesystem path.

This performs a stat(2) call and returns the owner UID from the resulting metadata. Missing files, permission errors, and invalid path bytes are surfaced as CoreError.

Errors

  • EACCES: Permission denied for a component of the path prefix.
  • ENOENT: The path does not exist.