Module property
coreshift_
core
2.0.0
Module property
Module Items
Structs
Traits
Functions
In coreshift_
core::
android
coreshift_core
::
android
Module
property
Structs

Android
Property
Info
Android
Property
Info
Opaque
Android
Property
Value
System
Android
Property
Store
Traits

Android
Property
Store
Functions

find
get
read
Read the current value of an Android system property.
serial
Return the current serial number of an Android system property.
set
Set an Android system property.
wait
Wait for an Android system property to change from its last known serial.