Structs
Traits
Functions
- android_
property_ find - android_
property_ get - android_
property_ read - Read the current value of an Android system property.
- android_
property_ serial - Return the current serial number of an Android system property.
- android_
property_ set - Set an Android system property.
- android_
property_ wait - Wait for an Android system property to change from its last known serial.