pub fn bind(
addr: UnixSocketAddr<'_>,
opts: UnixSocketBindOptions,
) -> Result<UnixListener, CoreError>Expand description
Bind a new Unix domain stream listener.
The socket is created with SOCK_CLOEXEC set.
Fork Safety
The socket is O_CLOEXEC and will be closed in the child after exec.
Errors
EACCES: Permission denied for a component of the path.EADDRINUSE: The address is already in use.EINVAL: Invalid address.ELOOP: Too many symbolic links encountered.ENAMETOOLONG: Path is too long.ENOENT: A component of the path prefix does not exist.