SpawnOptionsBuilder

Struct SpawnOptionsBuilder 

pub struct SpawnOptionsBuilder { /* private fields */ }
Builder for SpawnOptions.

Implementations

Source

impl SpawnOptionsBuilder

pub fn new(argv: Vec<String>, backend: SpawnBackend) -> Self

Create a new builder with the specified argument vector.

pub fn env(self, env: Vec<String>) -> Self

Set environment variables.

pub fn cwd(self, cwd: String) -> Self

Set the working directory.

pub fn stdin(self, data: impl Into<Box<[u8]>>) -> Self

Provide data to be written to the child’s stdin.

pub fn capture_stdout(self) -> Self

Enable stdout capture.

Examples found in repository?
examples/spawn_ls.rs (line 10)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    println!("Spawning '/bin/ls -l'...");
5
6    let output = SpawnOptions::builder(
7        vec!["/bin/ls".to_string(), "-l".to_string()],
8        SpawnBackend::PosixSpawn,
9    )
10    .capture_stdout()
11    .timeout_ms(5000)
12    .build()?
13    .run()?;
14
15    println!("Exit status: {:?}", output.status);
16    println!("Output length: {} bytes", output.stdout.len());
17    println!("--- STDOUT ---");
18    println!("{}", String::from_utf8_lossy(&output.stdout));
19    println!("--------------");
20
21    Ok(())
22}
pub fn capture_stderr(self) -> Self

Enable stderr capture.

pub fn wait(self, wait: bool) -> Self

Set whether to wait for the process to terminate (default: true).

pub fn pgroup(self, pgroup: ProcessGroup) -> Self

Set process group and isolation policy.

pub fn max_output(self, max: usize) -> Self

Set the combined stdout+stderr output buffer size (default: 1MB).

If captured output exceeds this limit, spawn drains the child pipes to completion and returns EOVERFLOW.

pub fn timeout_ms(self, ms: u32) -> Self

Set the execution timeout in milliseconds.

Examples found in repository?
examples/spawn_ls.rs (line 11)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    println!("Spawning '/bin/ls -l'...");
5
6    let output = SpawnOptions::builder(
7        vec!["/bin/ls".to_string(), "-l".to_string()],
8        SpawnBackend::PosixSpawn,
9    )
10    .capture_stdout()
11    .timeout_ms(5000)
12    .build()?
13    .run()?;
14
15    println!("Exit status: {:?}", output.status);
16    println!("Output length: {} bytes", output.stdout.len());
17    println!("--- STDOUT ---");
18    println!("{}", String::from_utf8_lossy(&output.stdout));
19    println!("--------------");
20
21    Ok(())
22}
pub fn kill_grace_ms(self, ms: u32) -> Self

Set the grace period before SIGKILL (default: 2s).

pub fn cancel(self, policy: CancelPolicy) -> Self

Set the cancellation policy (default: Kill).

pub fn fd_policy(self, policy: SpawnFdPolicy) -> Self

Set the child file-descriptor inheritance policy.

pub fn early_exit(self, callback: fn(&[u8]) -> bool) -> Self

Set an early exit callback.

pub fn build(self) -> Result<SpawnOptions, CoreError>

Build the spawn options.

Examples found in repository?
examples/spawn_ls.rs (line 12)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    println!("Spawning '/bin/ls -l'...");
5
6    let output = SpawnOptions::builder(
7        vec!["/bin/ls".to_string(), "-l".to_string()],
8        SpawnBackend::PosixSpawn,
9    )
10    .capture_stdout()
11    .timeout_ms(5000)
12    .build()?
13    .run()?;
14
15    println!("Exit status: {:?}", output.status);
16    println!("Output length: {} bytes", output.stdout.len());
17    println!("--- STDOUT ---");
18    println!("{}", String::from_utf8_lossy(&output.stdout));
19    println!("--------------");
20
21    Ok(())
22}