Ownership and UID lookup helpers.
These helpers provide cheap ownership probes for filesystem paths and
/proc/<pid> directories before higher layers do more expensive work.
Structs
- Path
Stat - Filesystem identity derived from
stat(2).
Functions
- chown_
path - Change the owner of a path while leaving the group unchanged when
gidisNone. - effective_
uid - Return the effective UID of the current process.
- path_
lstat - Return identity metadata for a filesystem path without following symbolic links.
- path_
stat - Return identity metadata for a filesystem path, following symbolic links.
- path_
uid - Return the owning UID for a filesystem path.
- proc_
stat - Return identity metadata for
/proc/<pid>. - proc_
stat_ at - Return identity metadata for
/proc/<pid>under an explicit procfs root. - proc_
uid - Return the owning UID for
/proc/<pid>. - proc_
uid_ at - Return the owning UID for
/proc/<pid>under an explicit procfs root.